@@ -94,7 +94,16 @@ class lines:
 
 		plt.plot(X,Y, color=color)
 
-	def show(self, save_path=None):
+	def show(self, save_path=None, title='', xlabel='', ylabel='', imgText=None, 
+					xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
+					xTextLoc=None, yTextLoc=None):
+
+		self.set_title(title, fontsize=self.title_font)
+		self.set_xlabel(xlabel, fontsize=self.xfont)
+		self.set_ylabel(ylabel, fontsize=self.yfont)
+		if imgText is not None:
+			self.add_text(X, Y, imgText, α=xTextShift, β=yTextShift, xTextLoc=xTextLoc, yTextLoc=yTextLoc)
+
 		if save_path is None: plt.show()
 		else: plt.savefig(save_path)
 
